==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.get_yy = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_zb = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.bj = function () {
        return new PriceVolumeTrendIndicator();
    };
    PriceVolumeTrendIndicator.prototype.get_abq = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_ab3 = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };
